@@ -44,11 +44,11 @@ Test::MockFile - Allows tests to validate code that can interact with files with
 
 =head1 VERSION
 
-Version 0.024
+Version 0.025
 
 =cut
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 our %files_being_mocked;
 
@@ -1855,8 +1855,8 @@ BEGIN {
 
             if ( !$mock ) {
                 _real_file_access_hook( 'chmod', \@_ );
-                goto \&CORE::chown if _goto_is_available();
-                return CORE::chown(@files);
+                goto \&CORE::chmod if _goto_is_available();
+                return CORE::chmod(@files);
             }
 
             # chmod is less specific in such errors
